@@ -137,13 +137,25 @@ static int game_loop() {
 	SDL_Event event;
 	while (running) {
 		if (SDL_WaitEvent(&event)) {
-			if (event.key.state == SDL_PRESSED) {
+			if (event.type == SDL_KEYDOWN) {
 				if (event.key.keysym.sym == SDLK_ESCAPE
 				|| event.key.keysym.sym == SDLK_F4
 				|| event.key.keysym.sym == SDLK_F5 
-				|| event.key.keysym.sym == SDLK_F6)
+				|| event.key.keysym.sym == SDLK_BACKSPACE)
 				running = 0;
 			}
+			if (event.type == SDL_ACTIVEEVENT){    /* Lose/gain visibility or focus */
+				// This controls the automatic pause when minimized.
+				// Instead of using a pause, gweled saves the game and quits, but 
+				//  only in timer mode
+				if (event.active.state & SDL_APPINPUTFOCUS) {
+					// If now in the background and in timed mode, save game and quit
+					if (!event.active.gain && game_timer_mode) {
+						running = 0;
+					}
+				}
+			}
+
 			game_lock();
 			switch (event.type) { 
 // Quit the game
@@ -152,10 +164,10 @@ static int game_loop() {
 				break;
 // Button pressed
 			case SDL_MOUSEBUTTONDOWN:
-				if (event.button.x < 46 && event.button.y > 396 && event.button.y < 438) {
+				if (event.button.x < 50 && event.button.y > 396 && event.button.y < 438) {
 					g_timer_mode ^= 1;
 					timer_status();	
-				} else if (event.button.x < 46 && event.button.y>438 && g_sound_on) {
+				} else if (event.button.x < 50 && event.button.y>438 && g_sound_on) {
 					g_music_on ^= 1;
 					if (g_music_on) {
 						if (!snd_music_start())
@@ -164,7 +176,7 @@ static int game_loop() {
 						snd_music_stop();
 					music_status();	
 //20100104 Sound mute hack--Flandry
-				} else if (event.button.x < 46 && event.button.y < 396 && event.button.y > 350) {
+				} else if (event.button.x < 50 && event.button.y < 396 && event.button.y > 345) {
 					g_sound_on ^= 1;
 					if (!g_sound_on) {
 						g_music_on = 0;
